@@ -11,6 +11,8 @@ import matplotlib as mpl
 import matplotlib.patches
 import matplotlib.collections
 
+import scipy.constants as constants 
+
 from scipy.fft import fft, fftfreq
 import NAFFlib # Numerical Analysis of the Fundamental Frequencies 
 
@@ -441,6 +443,15 @@ class particles:
         print(dash)
         print('\n')
 
+    def classical_particle_radius(particle_ref):
+        """ 
+        Method to calculate classical particle radius from given reference particle, also ions
+        """
+        q = 1.602176634e-19 # elementary charge 
+        m0 = particle_ref.mass0*1.782661921e-36  # electron volt - kg conversion
+        r0 = (particle_ref.q0*q)**2/(4*np.pi*constants.epsilon_0*m0*constants.c**2)  #1.5347e-18 is default for protons
+        return r0
+
 
 # Tools specifically for CPymad and MAD-X
 class madx_tools:
